==> wow_views-0.0.55.tar.gz: lib/components/view/button_dang_ky.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wow_views/interfaces/interface_action.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';

class ButtonDangKy {
  Widget getMainView(Map<String, dynamic> data, String tableName) {
    var dataReponse = Methods.getList(data['data'], tableName);
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    List<Map<String, Object>> dsAction = data['dsAction'];
    double height = 0;
    int id = 0;
    if (dataReponse.isNotEmpty) {
      height = Methods.getDouble(dataReponse[0], 'heightButton', defaultValue: 0);
      id = Methods.getInt(dataReponse[0], 'ID', defaultValue: 0);
    }
    if (height == 0) {
      height = 60;
    }
    return Container(
      width: Get.width,
      alignment: Alignment.center,
      child: Container(
        padding: const EdgeInsets.symmetric(vertical: 8),
        width: Get.width / 2,
        height: height,
        child: ElevatedButton(
          style: ButtonStyle(
            backgroundColor: MaterialStateProperty.resolveWith<Color>((state) {
              return const Color(0xFFF79750);
            }),
            padding: MaterialStateProperty.all<EdgeInsets>(
                const EdgeInsets.symmetric(horizontal: 16, vertical: 8)),
            shape: MaterialStateProperty.all<OutlinedBorder>(
              RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(10),
              ),
            ),
            minimumSize: MaterialStateProperty.all<Size>(const Size(0, 0)),
            tapTargetSize: MaterialTapTargetSize.shrinkWrap,
          ),
          onPressed: () {
            iAction
                .actionCompoment(4, dsAction, idData: id, params: {'@id': id});
          },
          child: Text(
            Message.getMessage('BUTTON_DANG_KY'),
            style: const TextStyle(
              color: Colors.white,
              fontWeight: FontWeight.bold,
              fontSize: 16,
            ),
          ),
        ),
      ),
    );
  }
}

==> wow_views-0.0.57.tar.gz: lib/components/view/button_dang_ky.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wow_views/interfaces/interface_action.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';

class ButtonDangKy {
  Widget getMainView(Map<String, dynamic> data, String tableName) {
    var dataReponse = Methods.getList(data['data'], tableName);
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    List<Map<String, Object>> dsAction = data['dsAction'];
    double height = 0;
    int id = 0;
    String keyTitle='';
    if (dataReponse.isNotEmpty) {
      height = Methods.getDouble(dataReponse.first, 'heightButton', defaultValue: 0);
      id = Methods.getInt(dataReponse.first, 'ID', defaultValue: 0);
      keyTitle = Methods.getString(dataReponse.first, 'keyTitle');
    }
    if (height == 0) {
      height = 60;
    }
    if(keyTitle.isEmpty){
      keyTitle = 'BUTTON_DANG_KY';
    }
    return Container(
      width: Get.width,
      alignment: Alignment.center,
      child: Container(
        padding: const EdgeInsets.symmetric(vertical: 8),
        width: Get.width / 2,
        height: height,
        child: ElevatedButton(
          style: ButtonStyle(
            backgroundColor: MaterialStateProperty.resolveWith<Color>((state) {
              return const Color(0xFFF79750);
            }),
            padding: MaterialStateProperty.all<EdgeInsets>(
                const EdgeInsets.symmetric(horizontal: 16, vertical: 8)),
            shape: MaterialStateProperty.all<OutlinedBorder>(
              RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(10),
              ),
            ),
            minimumSize: MaterialStateProperty.all<Size>(const Size(0, 0)),
            tapTargetSize: MaterialTapTargetSize.shrinkWrap,
          ),
          onPressed: () {
            iAction
                .actionCompoment(4, dsAction, idData: id, params: {'@id': id});
          },
          child: Text(
            Message.getMessage(keyTitle),
            style: const TextStyle(
              color: Colors.white,
              fontWeight: FontWeight.bold,
              fontSize: 16,
            ),
          ),
        ),
      ),
    );
  }
}
